@@ -1,11 +1,13 @@
 from .account import Account, Wallet4Account, SimpleAccount, CurrencyIssuerAccount
 from .client import Client
 from .exc import AmbisafeError, ServerError, ClientError
-from .transactions import Wallet4Transaction, RecoveryTransaction, GrantTransaction
+from .transactions import Wallet4Transaction, RecoveryTransaction, GrantTransaction, SimpleTransaction
 from .containers import Container
 from .crypt import Crypt, KEY_LENGTH
 
+__version__ = '0.23.1'
+
 __all__ = ['Client', 'ServerError', 'AmbisafeError', 'ClientError',
            'Account', 'Wallet4Account', 'SimpleAccount', 'CurrencyIssuerAccount', 'Container',
-           'Wallet4Transaction', 'RecoveryTransaction',
+           'SimpleTransaction', 'Wallet4Transaction', 'RecoveryTransaction',
            'GrantTransaction', 'Crypt', 'KEY_LENGTH']
