@@ -22,7 +22,7 @@ class Account(object):
         security_schema = response['account']['securitySchemaName']
 
         address = response['account']['address']
-        if security_schema == 'Wallet4':
+        if security_schema in ('Wallet4', 'Wallet4v2'):
             containers = {}
             for role, container in response.get('containers', {}).items():
                 try:
@@ -30,9 +30,13 @@ class Account(object):
                 except KeyError:
                     pass
                 containers[role] = Container.from_server_response(**container)
+            if security_schema == 'Wallet4':
+                version = 1
+            else:
+                version = 2
             return Wallet4Account(account_id, user_container=containers['USER'],
                                   operator_container=containers['OPERATOR'],
-                                  address=address)
+                                  address=address, version=version)
         elif security_schema == 'Simple':
             return SimpleAccount(account_id, address)
         elif security_schema == 'CurrencyIssuer':
@@ -54,6 +58,13 @@ class Account(object):
         """
         return json.dumps(self.as_dict())
 
+    @property
+    def security_schema(self):
+        return self._security_schema
+
+    def __repr__(self):
+        return '<Account id={} schema={} address={}>'.format(self.id, self._security_schema, self.address)
+
 
 class SimpleAccount(Account):
     def __init__(self, account_id, address=None, currency='BTC'):
@@ -83,12 +94,11 @@ class SimpleAccount(Account):
             'security_schema': self._security_schema,
         }
 
-    def __repr__(self):
-        return '<SimpleAccount id={} address={}>'.format(self.id, self.address)
-
 
 class Wallet4Account(Account):
-    def __init__(self, account_id, operator_container=None, user_container=None, address=None, currency='BTC'):
+    def __init__(self, account_id, operator_container=None,
+                 user_container=None, address=None, currency='BTC',
+                 version=1):
         """
         Creates Wallet4 account object
         :param account_id:
@@ -110,7 +120,12 @@ class Wallet4Account(Account):
         self.id = account_id
         self.currency = currency
         self.address = address
-        self._security_schema = 'Wallet4'
+        if version == 1:
+            self._security_schema = 'Wallet4'
+        elif version == 2:
+            self._security_schema = 'Wallet4v2'
+        else:
+            raise ValueError('Wrong Wallet4 version')
 
     def as_dict(self):
         """
@@ -146,9 +161,6 @@ class Wallet4Account(Account):
 
         return transaction
 
-    def __repr__(self):
-        return '<Wallet4Account id={} address={}>'.format(self.id, self.address)
-
 
 class CurrencyIssuerAccount(Account):
     def __init__(self, account_id, containers, address, currency=None):
