@@ -1,10 +1,14 @@
 import logging
+import random
 from uuid import uuid4
-from ecdsa import SECP256k1, SigningKey, util
-from pybitcointools import compress, privkey_to_pubkey
+from pycoin import ecdsa
+from pycoin.key import Key
+from pycoin.tx.script import der
 from ambisafe.crypt import Crypt
 
 logger = logging.getLogger('ambisafe')
+SIGHASH_ALL = 1
+order = ecdsa.generator_secp256k1.order()
 
 
 class Container(object):
@@ -22,6 +26,15 @@ class Container(object):
         self.iv = iv
         self.salt = salt
 
+    @classmethod
+    def generate_key_pair(cls):
+        key = Key(random.SystemRandom().randrange(1, order))
+        private_key = format(key.secret_exponent(), 'x')
+        if len(private_key) % 2:
+            private_key = '0' + private_key
+        public_key = key.sec_as_hex()
+        return private_key, public_key
+
     @classmethod
     def generate(cls, secret):
         """
@@ -30,13 +43,15 @@ class Container(object):
         :type secret: basestring
         :return: Container
         """
-        key = SigningKey.generate(curve=SECP256k1)
-        private_key = key.to_string().encode('hex')
-        compressed_public_key = compress(privkey_to_pubkey(private_key))
+        private_key, public_key = cls.generate_key_pair()
         crypt = Crypt(secret)
         salt = str(uuid4())
-        iv, encrypted_private_key = crypt.encrypt(private_key, salt)
-        return cls(compressed_public_key, encrypted_private_key, iv, salt)
+        try:
+            iv, encrypted_private_key = crypt.encrypt(private_key, salt)
+        except TypeError:
+            print private_key
+            raise
+        return cls(public_key, encrypted_private_key, iv, salt)
 
     @classmethod
     def from_server_response(cls, publicKey, data, iv, salt):
@@ -69,8 +84,11 @@ class Container(object):
         :param private_key:
         :return: str
         """
-        key = SigningKey.from_string(private_key.decode('hex'), curve=SECP256k1)
-        sig = key.sign_digest(message.decode('hex'), sigencode=util.sigencode_der) + '01'.decode('hex')
+        key = Key(int(private_key, 16))
+        r, s = ecdsa.sign(ecdsa.generator_secp256k1, key.secret_exponent(), int(message, 16))
+        if s + s > order:
+            s = order - s
+        sig = der.sigencode_der(r, s) + chr(SIGHASH_ALL)
         return sig.encode('hex')
 
     def __getitem__(self, item):
@@ -94,6 +112,6 @@ class Container(object):
         return container
 
     def __repr__(self):
-        return '<Container public_key="{}" data="{}" iv="{}" salt="{}">'.format(
+        return u'<Container public_key="{}" data="{}" iv="{}" salt="{}">'.format(
             self.publicKey, self.data, self.iv, self.salt
         )
